@@ -19,7 +19,9 @@ chrome.test.runTests([
 
   function bookmarks() {
     try {
-      chrome.bookmarks.get("1", pass(function(results) {}));
+      // Use getRecent() instead of get("1") because desktop Android doesn't
+      // create the bookmark bar (id "1") by default.
+      chrome.bookmarks.getRecent(1, pass(function (results) { }));
     } catch (e) {
       chrome.test.fail();
     }
