@@ -1,10 +1,10 @@
 // Copyright 2025 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
-import {ClientView, HostCapability, ScrollToErrorReason, WebClientMode} from '/glic/glic_api/glic_api.js';
+import {ClientView, HostCapability, MetricUserInputReactionType, ResponseStopCause, ScrollToErrorReason, WebClientMode} from '/glic/glic_api/glic_api.js';
 import type {FocusedTabData, GetPinCandidatesOptions, GlicBrowserHost, OpenPanelInfo, PageMetadata, PanelOpeningData, ScrollToError, UserProfileInfo, ViewChangeRequest, ZeroStateSuggestionsV2} from '/glic/glic_api/glic_api.js';
 
-import {ApiTestError, ApiTestFixtureBase, assertDefined, assertEquals, assertFalse, assertNotEquals, assertRejects, assertTrue, checkDefined, observeSequence, readStream, runUntil, sleep, testMain, waitFor, WebClient} from './browser_test_base.js';
+import {ApiTestError, ApiTestFixtureBase, assertDefined, assertEquals, assertFalse, assertNotEquals, assertRejects, assertTrue, assertUndefined, checkDefined, observeSequence, readStream, runUntil, sleep, testMain, waitFor, WebClient} from './browser_test_base.js';
 
 // Test cases here correspond to test cases in glic_api_browsertest.cc.
 // Since these tests run in the webview, this test can't use normal deps like
@@ -28,7 +28,9 @@ class ApiTests extends ApiTestFixtureBase {
     }
   }
 
-  async testRequestHeader() {}
+  async testRequestHeader() {
+    await fetch('/fake-rpc');
+  }
 
   async testCreateTab() {
     assertDefined(this.host.createTab);
@@ -573,11 +575,15 @@ class ApiTests extends ApiTestFixtureBase {
 
   async testGetDefaultTabContextPermissionState() {
     assertDefined(this.host.getDefaultTabContextPermissionState);
+
     const defaultTabContextState =
         observeSequence(this.host.getDefaultTabContextPermissionState());
-    assertTrue(await defaultTabContextState.next() as boolean);
+
+    assertFalse(await defaultTabContextState.next());
+
     await this.advanceToNextStep();
-    assertFalse(await defaultTabContextState.next() as boolean);
+
+    assertTrue(await defaultTabContextState.next());
   }
 
   async testGetOsHotkeyState() {
@@ -698,14 +704,16 @@ class ApiTests extends ApiTestFixtureBase {
     assertDefined(metrics);
     assertDefined(metrics.onResponseRated);
     assertDefined(metrics.onUserInputSubmitted);
+    assertDefined(metrics.onReaction);
     assertDefined(metrics.onResponseStarted);
     assertDefined(metrics.onResponseStopped);
     assertDefined(metrics.onSessionTerminated);
     assertDefined(metrics.onClosedCaptionsShown);
     metrics.onResponseRated(true);
-    metrics.onUserInputSubmitted(WebClientMode.AUDIO);
+    metrics.onUserInputSubmitted(WebClientMode.TEXT);
+    metrics.onReaction(MetricUserInputReactionType.MODEL);
     metrics.onResponseStarted();
-    metrics.onResponseStopped();
+    metrics.onResponseStopped({cause: ResponseStopCause.USER});
     metrics.onSessionTerminated();
     metrics.onClosedCaptionsShown();
   }
@@ -913,8 +921,7 @@ class ApiTests extends ApiTestFixtureBase {
     assertDefined(this.host.pinTabs);
     assertDefined(this.host.getPinnedTabs);
     assertDefined(this.host.unpinTabs);
-    const focus = this.host.getFocusedTabStateV2?.().getCurrentValue();
-    const tabId = checkDefined(focus?.hasFocus?.tabData.tabId);
+    const tabId = this.getFocusedTabId();
     await this.host.pinTabs([tabId]);
     const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
     await pinnedTabsUpdates.waitFor(
@@ -975,10 +982,8 @@ class ApiTests extends ApiTestFixtureBase {
     assertDefined(this.host.pinTabs);
     assertDefined(this.host.getPinnedTabs);
     assertDefined(this.host.unpinTabs);
-    assertDefined(this.host.getFocusedTabStateV2);
 
-    const focus = this.host.getFocusedTabStateV2?.().getCurrentValue();
-    const tabId = checkDefined(focus?.hasFocus?.tabData.tabId);
+    const tabId = this.getFocusedTabId();
     const nonExistTabId = 'not-exist';
     // Pinning a non existing tab id should fail.
     assertFalse(await this.host.pinTabs([tabId, nonExistTabId]));
@@ -992,14 +997,61 @@ class ApiTests extends ApiTestFixtureBase {
     await pinnedTabsUpdates.waitFor((tabs) => tabs.length === 0);
   }
 
+  async testPinTabsStatePersistWhenClosePanelAndReopen() {
+    assertDefined(this.host.closePanel);
+    assertDefined(this.host.pinTabs);
+    assertDefined(this.host.getPinnedTabs);
+
+    const tabId = this.testParams.tabId;
+    const focusedTabId = this.getFocusedTabId();
+
+    assertTrue(await this.host.pinTabs([focusedTabId, tabId]));
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+    await pinnedTabsUpdates.waitFor((tabs) => tabs.length === 2);
+
+    await this.host.closePanel();
+
+    // Open glic window again.
+    await this.advanceToNextStep();
+
+    assertEquals(this.host.getPinnedTabs().getCurrentValue()?.length, 2);
+  }
+
+  async testPinTabsStatePersistWhenClientRestarts() {
+    const isFirstRun: boolean = this.testParams.isFirstRun;
+
+    if (isFirstRun) {
+      assertDefined(this.host.pinTabs);
+      assertDefined(this.host.getPinnedTabs);
+
+      const tabId = this.testParams.tabId;
+      const focusedTabId = this.getFocusedTabId();
+
+      assertTrue(await this.host.pinTabs([focusedTabId, tabId]));
+      const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+      await pinnedTabsUpdates.waitFor((tabs) => tabs.length === 2);
+    } else {
+      assertEquals(this.host.getPinnedTabs?.().getCurrentValue()?.length, 2);
+    }
+  }
+
+  async testPinTabsFailsWhenIncognitoWindow() {
+    assertDefined(this.host.pinTabs);
+    assertDefined(this.host.getPinnedTabs);
+
+    assertFalse(await this.host.pinTabs([this.testParams.incognitoTabId]));
+
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+    await pinnedTabsUpdates.waitFor((tabs) => tabs.length === 0);
+  }
+
   async testUnpinTabsFailsWhenNotPinned() {
     assertDefined(this.host.pinTabs);
     assertDefined(this.host.getPinnedTabs);
     assertDefined(this.host.unpinTabs);
 
     const tabId = this.testParams.tabId;
-    const focus = this.host.getFocusedTabStateV2?.().getCurrentValue();
-    const tabId2 = checkDefined(focus?.hasFocus?.tabData.tabId);
+    const tabId2 = this.getFocusedTabId();
     // Pin both tabs.
     assertTrue(await this.host.pinTabs([tabId2, tabId]));
 
@@ -1015,6 +1067,53 @@ class ApiTests extends ApiTestFixtureBase {
     await pinnedTabsUpdates.waitFor((tabs) => tabs.length === 0);
   }
 
+  async testUnpinAllTabs() {
+    assertDefined(this.host.pinTabs);
+    assertDefined(this.host.getPinnedTabs);
+    assertDefined(this.host.unpinAllTabs);
+
+    const tabId = this.testParams.tabId;
+    const tabId2 = this.getFocusedTabId();
+
+    // Pin both tabs.
+    assertTrue(await this.host.pinTabs([tabId2, tabId]));
+
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+    await pinnedTabsUpdates.waitFor((tabs) => tabs.length === 2);
+
+    // Unpin all tabs.
+    this.host.unpinAllTabs();
+    await pinnedTabsUpdates.waitFor((tabs) => tabs.length === 0);
+  }
+
+  async testPinTabsHaveNoEffectOnFocusedTab() {
+    assertDefined(this.host.pinTabs);
+    assertDefined(this.host.unpinAllTabs);
+    assertDefined(this.host.getPinnedTabs);
+    assertDefined(this.host.getFocusedTabStateV2);
+
+    await this.host.setTabContextPermissionState(true);
+    const tabId: string = this.testParams.tabId;
+
+    const focusSequence = observeSequence(this.host.getFocusedTabStateV2());
+    const focus = await focusSequence.next();
+    const focusedTabId = checkDefined(focus?.hasFocus?.tabData.tabId);
+    // Make sure tabId is not the focused tab.
+    assertNotEquals(tabId, focusedTabId);
+
+    await this.host.pinTabs([tabId]);
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+    pinnedTabsUpdates.waitFor(
+        (tabs) => tabs.length === 1 && tabs.at(0)?.tabId === tabId);
+
+    assertTrue(focusSequence.isEmpty());
+
+    this.host.unpinAllTabs();
+    pinnedTabsUpdates.waitFor((tabs) => tabs.length === 0);
+
+    assertTrue(focusSequence.isEmpty());
+  }
+
   // Tests that tabs which navigate are unpinned if the glic window is closed.
   async testUnpinTabsThatNavigateInBackground() {
     assertDefined(this.host.getPinCandidates);
@@ -1045,6 +1144,54 @@ class ApiTests extends ApiTestFixtureBase {
             '?changedOne');
   }
 
+  async testTabDataUpdateOnUrlChangeForPinnedTab() {
+    assertDefined(this.host.getPinnedTabs);
+    assertDefined(this.host.pinTabs);
+
+    const tabId = this.testParams.tabId;
+    assertNotEquals(tabId, this.getFocusedTabId());
+
+    await this.host.pinTabs([tabId]);
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+    await pinnedTabsUpdates.waitFor(
+        (tabs) => tabs.some(t => t.tabId === tabId));
+
+    // Navigate to a different URL.
+    await this.advanceToNextStep();
+
+    // Make sure that the pinned tab is not focused.
+    assertNotEquals(tabId, this.getFocusedTabId());
+    await pinnedTabsUpdates.waitFor(
+        (tabs) =>
+            tabs.some(t => t.tabId === tabId && t.url.includes('changed')));
+  }
+
+  async testTabDataUpdateOnFaviconChangeForPinnedTab() {
+    assertDefined(this.host.getPinnedTabs);
+    assertDefined(this.host.pinTabs);
+
+    const tabId = this.testParams.tabId;
+    assertNotEquals(tabId, this.getFocusedTabId());
+
+    await this.host.pinTabs([tabId]);
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+
+    await pinnedTabsUpdates.waitFor(
+        (tabs) => tabs.length === 1 &&
+            tabs.some(t => t.tabId === tabId && t.favicon === undefined));
+
+    // Update the favicon.
+    await this.advanceToNextStep();
+
+    const [tabData] = await pinnedTabsUpdates.waitFor(
+        (tabs) => tabs.length === 1 &&
+            tabs.some(t => t.tabId === tabId && t.favicon !== undefined));
+
+    const blob = await tabData?.favicon?.();
+    assertEquals(blob?.type, 'image/png');
+  }
+
+
   // Helper to get focused tabId.
   getFocusedTabId(): string {
     assertDefined(this.host.getFocusedTabStateV2);
@@ -1338,12 +1485,26 @@ class ApiTests extends ApiTestFixtureBase {
     sequence.waitFor(tabs => tabs.length === 2);
   }
 
-  async testGetModelQualityClientId() {
+  async testGetModelQualityClientIdFeatureEnabled() {
+    assertDefined(this.host.getHostCapabilities);
+    const capabilities: Set<HostCapability> =
+        await this.host.getHostCapabilities();
+    assertTrue(capabilities.has(HostCapability.GET_MODEL_QUALITY_CLIENT_ID));
+
     assertDefined(this.host.getModelQualityClientId);
     const clientId = await this.host.getModelQualityClientId();
     assertDefined(clientId);
   }
 
+  async testGetModelQualityClientIdFeatureDisabled() {
+    assertDefined(this.host.getHostCapabilities);
+    const capabilities: Set<HostCapability> =
+        await this.host.getHostCapabilities();
+    assertFalse(capabilities.has(HostCapability.GET_MODEL_QUALITY_CLIENT_ID));
+
+    assertUndefined(this.host.getModelQualityClientId);
+  }
+
 /**
    * A basic test to verify that `getPageMetadata` correctly retrieves metadata
    * for a given tab.
@@ -1381,11 +1542,8 @@ class ApiTests extends ApiTestFixtureBase {
     assertDefined(metadataObservable);
     const metadataSequence = observeSequence(metadataObservable);
 
-    // The observable should not emit any more values.
-    // Wait a bit to ensure that any spurious updates would have been received.
-    await sleep(500);
-    // TODO(gklassen): update this to assert that the observable is completed
-    // once observeSequence is updated to handle complete.
+    // The observable should not emit any values, and should complete.
+    await metadataSequence.completed;
     assertTrue(metadataSequence.isEmpty());
   }
 
@@ -1500,11 +1658,8 @@ class ApiTests extends ApiTestFixtureBase {
     // Close the tab.
     await this.advanceToNextStep();
 
-    // The observable should not emit any more values.
-    // Wait a bit to ensure that any spurious updates would have been received.
-    await sleep(500);
-    // TODO(gklassen): update this to assert that the observable is completed
-    // once observeSequence is updated to handle complete.
+    // The observable should not emit any more values, and should complete.
+    await metadataSequence.completed;
     assertTrue(metadataSequence.isEmpty());
   }
 
@@ -1577,6 +1732,8 @@ class ApiTests extends ApiTestFixtureBase {
         return 'SCROLL_TO_PDF';
       case HostCapability.RESET_SIZE_AND_LOCATION_ON_OPEN:
         return 'RESET_SIZE_AND_LOCATION_ON_OPEN';
+      case HostCapability.GET_MODEL_QUALITY_CLIENT_ID:
+        return 'GET_MODEL_QUALITY_CLIENT_ID';
       default:
         return 'NEW_ENUM_NOT_IMPLEMENTED';
     }
