@@ -169,7 +169,7 @@ suite('NewTabPageComposeboxTest', () => {
 
   async function uploadFileAndVerify(token: Object, file: File) {
     // Assert no files.
-    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
+    assertEquals(composeboxElement.$.carousel.files.length, 0);
 
     handler.setResultFor(ADD_FILE_CONTEXT_FN, Promise.resolve({token: token}));
 
@@ -240,7 +240,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Check submit button disabled and files empty.
     assertStyle(composeboxElement.$.submitIcon, 'cursor', 'default');
-    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
+    assertEquals(composeboxElement.$.carousel.files.length, 0);
 
     // Close composebox.
     const whenCloseComposebox =
@@ -402,7 +402,8 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Assert no files uploaded or rendered on the carousel
     assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 0);
-    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
+    const files = composeboxElement.$.carousel.files;
+    assertEquals(files.length, 0);
     assertEquals(
         1,
         metrics.count(
@@ -428,7 +429,8 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Assert no files uploaded or rendered on the carousel
     assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 0);
-    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
+    const files = composeboxElement.$.carousel.files;
+    assertEquals(files.length, 0);
     assertEquals(
         1,
         metrics.count(
@@ -462,7 +464,8 @@ suite('NewTabPageComposeboxTest', () => {
           await callbackRouterRemote.$.flushForTesting();
 
           // Assert no files in the carousel.
-          assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
+          const files = composeboxElement.$.carousel.files;
+          assertEquals(files.length, 0);
         });
   });
 
@@ -473,7 +476,7 @@ suite('NewTabPageComposeboxTest', () => {
         Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
 
     // Assert no files.
-    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
+    assertEquals(composeboxElement.$.carousel.files.length, 0);
 
     // Arrange.
     const dataTransfer = new DataTransfer();
@@ -881,13 +884,13 @@ suite('NewTabPageComposeboxTest', () => {
       key: 'ArrowDown',
     });
 
-    composeboxElement.$.input.dispatchEvent(arrowDownEvent);
+    composeboxElement.dispatchEvent(arrowDownEvent);
     await microtasksFinished();
-    assertTrue(arrowDownEvent.defaultPrevented);
+    assertFalse(arrowDownEvent.defaultPrevented);
 
-    // First match is selected
-    assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
-    assertEquals('hello world', composeboxElement.$.input.value);
+    // First match is not selected as focus is in input
+    assertFalse(matchEls[0]!.hasAttribute(Attributes.SELECTED));
+    assertEquals('', composeboxElement.$.input.value);
 
     // Move the focus to the second match.
     matchEls[1]!.focus();
@@ -925,109 +928,6 @@ suite('NewTabPageComposeboxTest', () => {
     loadTimeData.overrideValues({composeboxShowZps: false});
   });
 
-  test('Selection is restored after selected match is removed', async () => {
-    loadTimeData.overrideValues(
-        {composeboxShowZps: true, composeboxShowTypedSuggest: true});
-    createComposeboxElement();
-    await microtasksFinished();
-
-    composeboxElement.$.input.value = '';
-    composeboxElement.$.input.dispatchEvent(new InputEvent('input'));
-
-    let matches = [
-      createSearchMatch({
-        supportsDeletion: true,
-      }),
-    ];
-    searchboxCallbackRouterRemote.autocompleteResultChanged(
-        createAutocompleteResult({
-          input:
-              stringToMojoString16(composeboxElement.$.input.value.trimStart()),
-          matches,
-        }));
-    await microtasksFinished();
-    assertTrue(await areMatchesShowing());
-
-    let matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
-    assertEquals(1, matchEls.length);
-    // First match is not selected.
-    assertFalse(matchEls[0]!.hasAttribute(Attributes.SELECTED));
-
-    // Remove the first match.
-    matchEls[0]!.$.remove.click();
-    const args = await searchboxHandler.whenCalled('deleteAutocompleteMatch');
-    assertEquals(0, args[0]);
-    assertEquals(1, searchboxHandler.getCallCount('deleteAutocompleteMatch'));
-
-    searchboxHandler.reset();
-
-    matches = [
-      createSearchMatch({supportsDeletion: true}), createSearchMatch({
-        supportsDeletion: true,
-        fillIntoEdit: stringToMojoString16('hello world 2'),
-      }),
-    ];
-    searchboxCallbackRouterRemote.autocompleteResultChanged(
-        createAutocompleteResult({
-          input: stringToMojoString16(''),
-          matches: matches,
-        }));
-    assertTrue(await areMatchesShowing());
-
-    matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
-    assertEquals(2, matchEls.length);
-
-    // First match is not selected.
-    assertFalse(matchEls[0]!.hasAttribute(Attributes.SELECTED));
-
-    const arrowDownEvent = new KeyboardEvent('keydown', {
-      bubbles: true,
-      cancelable: true,
-      composed: true,  // So it propagates across shadow DOM boundary.
-      key: 'ArrowDown',
-    });
-
-    composeboxElement.$.input.dispatchEvent(arrowDownEvent);
-    await microtasksFinished();
-    assertTrue(arrowDownEvent.defaultPrevented);
-
-    // First match is selected
-    assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
-    assertEquals('hello world', composeboxElement.$.input.value);
-
-    // By pressing 'Enter' on the button.
-    const keydownEvent = (new KeyboardEvent('keydown', {
-      bubbles: true,
-      cancelable: true,
-      composed: true,
-      key: 'Enter',
-    }));
-    assertTrue(!!matchEls[0]!.$.remove);
-    matchEls[0]!.$.remove.dispatchEvent(keydownEvent);
-    assertTrue(keydownEvent.defaultPrevented);
-    const keydownArgs =
-        await searchboxHandler.whenCalled('deleteAutocompleteMatch');
-    await microtasksFinished();
-    assertEquals(0, keydownArgs[0]);
-    assertEquals(1, searchboxHandler.getCallCount('deleteAutocompleteMatch'));
-
-    matches = [createSearchMatch({
-      supportsDeletion: true,
-      fillIntoEdit: stringToMojoString16('hello world 2'),
-    })];
-    searchboxCallbackRouterRemote.autocompleteResultChanged(
-        createAutocompleteResult({
-          input: stringToMojoString16(''),
-          matches: matches,
-        }));
-    assertTrue(await areMatchesShowing());
-
-    assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
-    assertEquals('hello world 2', composeboxElement.$.input.value);
-  });
-
   test('smart compose response added', async () => {
     createComposeboxElement();
     await microtasksFinished();
@@ -1093,42 +993,6 @@ suite('NewTabPageComposeboxTest', () => {
     assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 0);
   });
 
-  test('composebox does not show when image is present', async () => {
-    loadTimeData.overrideValues({
-      composeboxShowZps: true,
-      composeboxShowTypedSuggest: true,
-      composeboxShowImageSuggest: false,
-    });
-    createComposeboxElement();
-    // Autocomplete queried once when composebox is created.
-    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
-
-    const matches = [createSearchMatch()];
-    searchboxCallbackRouterRemote.autocompleteResultChanged(
-        createAutocompleteResult({
-          input: stringToMojoString16(''),
-          matches,
-        }));
-    assertTrue(await areMatchesShowing());
-
-    // Upload an image.
-    const id = generateZeroId();
-    await uploadFileAndVerify(
-        id, new File(['foo'], 'foo.jpg', {type: 'image/jpeg'}));
-
-    callbackRouterRemote.onContextualInputStatusChanged(
-        id, FileUploadStatus.kUploadSuccessful, null);
-
-    // Matches should not show when image is present.
-    assertFalse(await areMatchesShowing());
-
-    // Do not query autocomplete with image present.
-    composeboxElement.$.input.value = 'T';
-    composeboxElement.$.input.dispatchEvent(new Event('input'));
-    await microtasksFinished();
-    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
-  });
-
   test('delete button removes match', async () => {
     loadTimeData.overrideValues({composeboxShowZps: true});
     createComposeboxElement();
@@ -1237,7 +1101,7 @@ suite('NewTabPageComposeboxTest', () => {
           Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
 
       // Assert no files.
-      assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
+      assertEquals(composeboxElement.$.carousel.files.length, 0);
 
       const contextMenuButton = $$(composeboxElement, '#contextEntrypoint');
       assertTrue(!!contextMenuButton);
