@@ -101,10 +101,7 @@ export function setThirdPartyCookieBlockingSetting(
 export function shouldShowCookiesCard(page: SettingsPrivacyGuidePageElement):
     boolean {
   return page.getPref('generated.cookie_default_content_setting').value !==
-      ContentSetting.BLOCK &&
-      (page.getPref('profile.cookie_controls_mode').value !==
-           CookieControlsMode.OFF ||
-       loadTimeData.getBoolean('isAlwaysBlock3pcsIncognitoEnabled'));
+      ContentSetting.BLOCK;
 }
 
 // Set the safe browsing setting for the privacy guide.
