@@ -3,7 +3,7 @@
 // found in the LICENSE file.
 import 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 
-import {AxReadAloudNode, BrowserProxy, NodeStore, previousReadHighlightClass, ReadAloudHighlighter, setInstance, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {BrowserProxy, NodeStore, previousReadHighlightClass, ReadAloudHighlighter, ReadAloudNode, setInstance, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 import {assertEquals, assertFalse, assertStringContains, assertStringExcludes, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
 
 import {FakeReadingMode} from './fake_reading_mode.js';
@@ -67,7 +67,7 @@ suite('Highlighter', () => {
     sentence.appendChild(document.createTextNode(text1 + text2));
     nodeStore.setDomNode(sentence, nodeId);
     const segments = [{
-      node: new AxReadAloudNode(nodeId),
+      node: ReadAloudNode.create(sentence)!,
       start: text1.length,
       length: text2.length,
     }];
@@ -78,7 +78,7 @@ suite('Highlighter', () => {
         /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
-    assertTrue(highlighter.hasCurrentHighlights());
+    assertTrue(highlighter.hasCurrentGranularity());
     assertHtml(
         '<span class="previous-read-highlight">' + text1 + '</span>' +
             '<span class="current-read-highlight">' + text2 + '</span>',
@@ -99,8 +99,8 @@ suite('Highlighter', () => {
     nodeStore.setDomNode(sentence, id1);
     nodeStore.setDomNode(bold, id2);
     const segments = [
-      {node: new AxReadAloudNode(id1), start: 0, length: text1.length},
-      {node: new AxReadAloudNode(id2), start: 0, length: text2.length},
+      {node: ReadAloudNode.create(sentence)!, start: 0, length: text1.length},
+      {node: ReadAloudNode.create(bold)!, start: 0, length: text2.length},
     ];
     readAloudModel.setCurrentTextSegments(segments);
 
@@ -109,7 +109,7 @@ suite('Highlighter', () => {
         /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
-    assertTrue(highlighter.hasCurrentHighlights());
+    assertTrue(highlighter.hasCurrentGranularity());
     assertFullNodeIsHighlighted(id1, text1);
     assertFullNodeIsHighlighted(id2, text2);
   });
@@ -124,8 +124,9 @@ suite('Highlighter', () => {
     const text = 'Woke up today, feeling the way I always do. ';
     sentence.appendChild(document.createTextNode(text));
     nodeStore.setDomNode(sentence, id);
-    const segments =
-        [{node: new AxReadAloudNode(id), start: 0, length: text.length}];
+    const segments = [
+      {node: ReadAloudNode.create(sentence)!, start: 0, length: text.length},
+    ];
     readAloudModel.setCurrentTextSegments(segments);
 
     highlighter.highlightCurrentGranularity(
@@ -133,7 +134,7 @@ suite('Highlighter', () => {
         /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
-    assertTrue(highlighter.hasCurrentHighlights());
+    assertTrue(highlighter.hasCurrentGranularity());
     assertFullNodeIsHighlighted(id, text);
   });
 
@@ -142,19 +143,20 @@ suite('Highlighter', () => {
         chrome.readingMode.wordHighlighting);
     wordBoundaries.updateBoundary(0);
     const id = 10;
-    const highlights = [{node: new AxReadAloudNode(id), start: 5, length: 5}];
-    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
     const sentence = document.createElement('p');
     sentence.appendChild(document.createTextNode(
         'Will your your eyes still smile from your cheeks?'));
     nodeStore.setDomNode(sentence, id);
+    const highlights =
+        [{node: ReadAloudNode.create(sentence)!, start: 5, length: 5}];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
 
     highlighter.highlightCurrentGranularity(
         highlights,
         /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
-    assertTrue(highlighter.hasCurrentHighlights());
+    assertTrue(highlighter.hasCurrentGranularity());
     assertHtml(
         '<span class="previous-read-highlight">Will </span>' +
             '<span class="current-read-highlight">your </span>' +
@@ -163,22 +165,28 @@ suite('Highlighter', () => {
   });
 
   test(
-      'onWillMoveToNextGranularity with word highlighting highlights the rest of the sentence',
+      'onWillMoveToNextGranularity with word highlighting highlights the rest' +
+          ' of the sentence',
       () => {
         chrome.readingMode.onHighlightGranularityChanged(
             chrome.readingMode.wordHighlighting);
         wordBoundaries.updateBoundary(0);
         const id = 10;
-        const highlights =
-            [{node: new AxReadAloudNode(id), start: 0, length: 3}];
-        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
         const sentence = document.createElement('p');
         const text = 'Do you believe in life after love?';
         sentence.appendChild(document.createTextNode(text));
         nodeStore.setDomNode(sentence, id);
+        const highlights =
+            [{node: ReadAloudNode.create(sentence)!, start: 0, length: 3}];
+        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
         chrome.readingMode.getTextContent = () => text;
-        const segments =
-            [{node: new AxReadAloudNode(id), start: 0, length: text.length}];
+        const segments = [
+          {
+            node: ReadAloudNode.create(sentence)!,
+            start: 0,
+            length: text.length,
+          },
+        ];
         readAloudModel.setCurrentTextSegments(segments);
         highlighter.highlightCurrentGranularity(
             segments,
@@ -186,7 +194,7 @@ suite('Highlighter', () => {
             /*shouldUpdateSentenceHighlight=*/ true);
         highlighter.onWillMoveToNextGranularity(segments);
 
-        assertFalse(highlighter.hasCurrentHighlights());
+        assertFalse(highlighter.hasCurrentGranularity());
         assertHtml(
             '<span class="previous-read-highlight">Do you believe in life ' +
                 'after love?</span>',
@@ -208,20 +216,20 @@ suite('Highlighter', () => {
     sentence.appendChild(document.createTextNode(text2));
     const id1 = 10;
     const id2 = 12;
-    const highlights = [
-      {node: new AxReadAloudNode(id1), start: 0, length: 3},
-      {node: new AxReadAloudNode(id2), start: 0, length: 1},
-    ];
-    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
     nodeStore.setDomNode(bold, id1);
     nodeStore.setDomNode(sentence, id2);
+    const highlights = [
+      {node: ReadAloudNode.create(bold)!, start: 0, length: 3},
+      {node: ReadAloudNode.create(sentence)!, start: 0, length: 1},
+    ];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
 
     highlighter.highlightCurrentGranularity(
         highlights,
         /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
-    assertTrue(highlighter.hasCurrentHighlights());
+    assertTrue(highlighter.hasCurrentGranularity());
 
     // Only "I'm" is highlighted. The rest of the sentence, including the space
     // after "I'm" remains unhighlighted.
@@ -237,25 +245,25 @@ suite('Highlighter', () => {
     const sentenceText = 'And I can\'t sweep you off of your feet';
     const punctuation = '.';
 
-    // Mock the backend to return a segment for just the punctuation.
-    const highlights = [{
-      node: new AxReadAloudNode(id),
-      start: sentenceText.length,
-      length: 1,
-    }];
-    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
-
     const sentence = document.createElement('p');
     sentence.appendChild(document.createTextNode(sentenceText + punctuation));
     nodeStore.setDomNode(sentence, id);
 
+    // Mock the backend to return a segment for just the punctuation.
+    const highlights = [{
+      node: ReadAloudNode.create(sentence)!,
+      start: sentenceText.length,
+      length: 1,
+    }];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
     highlighter.highlightCurrentGranularity(
         highlights,
         /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
-    // There should be no "current" highlight on the page.
-    assertFalse(highlighter.hasCurrentHighlights());
+    // There should be no "current" highlight on the page, but there is a
+    // current granularity in terms of movement.
+    assertTrue(highlighter.hasCurrentGranularity());
     assertHtml(
         '<span class="previous-read-highlight">' + sentenceText +
             '</span><span class="previous-read-highlight">' + punctuation +
@@ -268,19 +276,20 @@ suite('Highlighter', () => {
         chrome.readingMode.autoHighlighting);
     wordBoundaries.updateBoundary(0);
     const id = 10;
-    const highlights = [{node: new AxReadAloudNode(id), start: 12, length: 20}];
-    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
     const sentence = document.createElement('p');
     sentence.appendChild(document.createTextNode(
         'But darling I will be loving you till we\'re 70.'));
     nodeStore.setDomNode(sentence, id);
+    const highlights =
+        [{node: ReadAloudNode.create(sentence)!, start: 12, length: 20}];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
 
     highlighter.highlightCurrentGranularity(
         highlights,
         /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
-    assertTrue(highlighter.hasCurrentHighlights());
+    assertTrue(highlighter.hasCurrentGranularity());
     assertHtml(
         '<span class="previous-read-highlight">But darling </span>' +
             '<span class="current-read-highlight">I will be loving you' +
@@ -289,22 +298,29 @@ suite('Highlighter', () => {
   });
 
   test(
-      'onWillMoveToNextGranularity with phrase highlighting highlights the rest of the sentence',
+      'onWillMoveToNextGranularity with phrase highlighting highlights the ' +
+          'rest of the sentence',
       () => {
         chrome.readingMode.onHighlightGranularityChanged(
             chrome.readingMode.autoHighlighting);
         wordBoundaries.updateBoundary(0);
         const id = 10;
-        const highlights =
-            [{node: new AxReadAloudNode(id), start: 0, length: 2}];
-        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
         const sentence = document.createElement('p');
         const text = 'I can feel something inside me say';
         sentence.appendChild(document.createTextNode(text));
         nodeStore.setDomNode(sentence, id);
+        const highlights =
+            [{node: ReadAloudNode.create(sentence)!, start: 0, length: 2}];
+        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+
         chrome.readingMode.getTextContent = () => text;
-        const segments =
-            [{node: new AxReadAloudNode(id), start: 0, length: text.length}];
+        const segments = [
+          {
+            node: ReadAloudNode.create(sentence)!,
+            start: 0,
+            length: text.length,
+          },
+        ];
         readAloudModel.setCurrentTextSegments(segments);
         highlighter.highlightCurrentGranularity(
             segments,
@@ -312,7 +328,7 @@ suite('Highlighter', () => {
             /*shouldUpdateSentenceHighlight=*/ true);
         highlighter.onWillMoveToNextGranularity(segments);
 
-        assertFalse(highlighter.hasCurrentHighlights());
+        assertFalse(highlighter.hasCurrentGranularity());
         assertHtml(
             '<span class="previous-read-highlight">I can feel something ' +
                 'inside me say</span>',
@@ -335,8 +351,8 @@ suite('Highlighter', () => {
     nodeStore.setDomNode(sentence, id1);
     nodeStore.setDomNode(bold, id2);
     const highlights = [
-      {node: new AxReadAloudNode(id1), start: 10, length: 9},
-      {node: new AxReadAloudNode(id2), start: 0, length: 23},
+      {node: ReadAloudNode.create(sentence)!, start: 10, length: 9},
+      {node: ReadAloudNode.create(bold)!, start: 0, length: 23},
     ];
     readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
 
@@ -346,7 +362,7 @@ suite('Highlighter', () => {
         /*shouldUpdateSentenceHighlight=*/ true);
 
 
-    assertTrue(highlighter.hasCurrentHighlights());
+    assertTrue(highlighter.hasCurrentGranularity());
     assertHtml(
         '<span class="previous-read-highlight">And honey </span>' +
             '<span class="current-read-highlight">your soul</span>',
@@ -365,80 +381,26 @@ suite('Highlighter', () => {
         chrome.readingMode.onSpeechRateChange(1);
         wordBoundaries.updateBoundary(0);
         const id = 10;
-        const highlights =
-            [{node: new AxReadAloudNode(id), start: 0, length: 20}];
-        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
         const sentence = document.createElement('p');
         sentence.appendChild(document.createTextNode(
             'Hungry for something that I can\'t eat. '));
         nodeStore.setDomNode(sentence, id);
+        const highlights =
+            [{node: ReadAloudNode.create(sentence)!, start: 0, length: 20}];
+        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
 
         highlighter.highlightCurrentGranularity(
             [],
             /*scrollIntoView=*/ false,
             /*shouldUpdateSentenceHighlight=*/ true);
 
-        assertTrue(highlighter.hasCurrentHighlights());
+        assertTrue(highlighter.hasCurrentGranularity());
         assertHtml(
             '<span class="current-read-highlight">Hungry for something</span>' +
                 ' that I can\'t eat. ',
             id);
       });
 
-  test('remove current highlight', () => {
-    chrome.readingMode.onHighlightGranularityChanged(
-        chrome.readingMode.sentenceHighlighting);
-    const id = 10;
-    const sentence = document.createElement('p');
-    const text1 =
-        'I\'m thinkin bout how people fall in love in mysterious ways.';
-    const text2 = ' Maybe just a touch of the hand';
-    sentence.appendChild(document.createTextNode(text1 + text2));
-    nodeStore.setDomNode(sentence, id);
-    const segments = [{
-      node: new AxReadAloudNode(id),
-      start: text1.length,
-      length: text1.length + text2.length,
-    }];
-    readAloudModel.setCurrentTextSegments(segments);
-
-    highlighter.highlightCurrentGranularity(
-        segments,
-        /*scrollIntoView=*/ false,
-        /*shouldUpdateSentenceHighlight=*/ true);
-    highlighter.removeCurrentHighlight(segments);
-
-    assertFalse(highlighter.hasCurrentHighlights());
-    assertHtmlContains(previousReadHighlightClass, id);
-  });
-
-  test('reset previous highlight', () => {
-    chrome.readingMode.onHighlightGranularityChanged(
-        chrome.readingMode.sentenceHighlighting);
-    const id = 10;
-    const sentence = document.createElement('p');
-    const text1 =
-        'I\'m thinkin bout how people fall in love in mysterious ways.';
-    const text2 = ' Maybe just a touch of the hand';
-    sentence.appendChild(document.createTextNode(text1 + text2));
-    nodeStore.setDomNode(sentence, id);
-    const segments = [{
-      node: new AxReadAloudNode(id),
-      start: text1.length,
-      length: text1.length + text2.length,
-    }];
-    readAloudModel.setCurrentTextSegments(segments);
-
-    highlighter.highlightCurrentGranularity(
-        segments,
-        /*scrollIntoView=*/ false,
-        /*shouldUpdateSentenceHighlight=*/ true);
-    highlighter.resetPreviousHighlight();
-
-    assertFalse(highlighter.hasCurrentHighlights());
-    assertHtmlContains(previousReadHighlightClass, id);
-  });
-
   test('clear highlights', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.sentenceHighlighting);
@@ -450,7 +412,7 @@ suite('Highlighter', () => {
     sentence.appendChild(document.createTextNode(text1 + text2));
     nodeStore.setDomNode(sentence, id);
     const segments = [{
-      node: new AxReadAloudNode(id),
+      node: ReadAloudNode.create(sentence)!,
       start: text1.length,
       length: text1.length + text2.length,
     }];
@@ -462,7 +424,117 @@ suite('Highlighter', () => {
         /*shouldUpdateSentenceHighlight=*/ true);
     highlighter.clearHighlightFormatting();
 
-    assertFalse(highlighter.hasCurrentHighlights());
+    assertFalse(highlighter.hasCurrentGranularity());
     assertHtmlExcludes(previousReadHighlightClass, id);
   });
+
+  test('reset clears all highlights and state', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.sentenceHighlighting);
+    const id = 10;
+    const sentence = document.createElement('p');
+    const text = 'This is a sentence.';
+    sentence.appendChild(document.createTextNode(text));
+    nodeStore.setDomNode(sentence, id);
+    const segments = [
+      {node: ReadAloudNode.create(sentence)!, start: 0, length: text.length},
+    ];
+    readAloudModel.setCurrentTextSegments(segments);
+    highlighter.highlightCurrentGranularity(
+        segments, /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+    assertTrue(highlighter.hasCurrentGranularity());
+
+    highlighter.reset();
+
+    assertFalse(highlighter.hasCurrentGranularity());
+    assertHtmlExcludes(previousReadHighlightClass, id);
+  });
+
+  test('restorePreviousHighlighting reapplies formatting after clear', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.sentenceHighlighting);
+    const id = 10;
+    const sentence = document.createElement('p');
+    const text = 'This is a sentence.';
+    sentence.appendChild(document.createTextNode(text));
+    nodeStore.setDomNode(sentence, id);
+    const segments = [
+      {node: ReadAloudNode.create(sentence)!, start: 0, length: text.length},
+    ];
+    readAloudModel.setCurrentTextSegments(segments);
+    highlighter.highlightCurrentGranularity(segments, false, true);
+    highlighter.onWillMoveToNextGranularity(segments);
+
+    // This should clear formatting but keep the granularity in the queue.
+    highlighter.clearHighlightFormatting();
+    highlighter.restorePreviousHighlighting();
+
+    assertHtmlContains(previousReadHighlightClass, id);
+  });
+
+  test(
+      'restorePreviousHighlighting does not reapply formatting after reset',
+      () => {
+        chrome.readingMode.onHighlightGranularityChanged(
+            chrome.readingMode.sentenceHighlighting);
+        const id = 10;
+        const sentence = document.createElement('p');
+        const text = 'This is a sentence.';
+        sentence.appendChild(document.createTextNode(text));
+        nodeStore.setDomNode(sentence, id);
+        const segments = [
+          {
+            node: ReadAloudNode.create(sentence)!,
+            start: 0,
+            length: text.length,
+          },
+        ];
+        readAloudModel.setCurrentTextSegments(segments);
+        highlighter.highlightCurrentGranularity(segments, false, true);
+        highlighter.onWillMoveToNextGranularity(segments);
+
+        highlighter.reset();
+        highlighter.restorePreviousHighlighting();
+
+        assertHtmlExcludes(previousReadHighlightClass, id);
+      });
+
+  test(
+      'onWillMoveToPreviousGranularity clears current and previous highlight',
+      () => {
+        chrome.readingMode.onHighlightGranularityChanged(
+            chrome.readingMode.sentenceHighlighting);
+        const id = 10;
+        const sentence = document.createElement('p');
+        const text1 = 'Me I fall in love with you every single day.';
+        const text2 = ' And I just wanna tell you I am';
+        sentence.appendChild(document.createTextNode(text1 + text2));
+        nodeStore.setDomNode(sentence, id);
+        const sentence1 = [{
+          node: ReadAloudNode.create(sentence)!,
+          start: 0,
+          length: text1.length,
+        }];
+        const sentence2 = [{
+          node: ReadAloudNode.create(sentence)!,
+          start: text1.length + 1,
+          length: text2.length,
+        }];
+        readAloudModel.setCurrentTextSegments(sentence1);
+
+        highlighter.highlightCurrentGranularity(
+            sentence1,
+            /*scrollIntoView=*/ false,
+            /*shouldUpdateSentenceHighlight=*/ true);
+        highlighter.onWillMoveToNextGranularity(sentence1);
+        highlighter.highlightCurrentGranularity(
+            sentence2,
+            /*scrollIntoView=*/ false,
+            /*shouldUpdateSentenceHighlight=*/ true);
+        highlighter.onWillMoveToPreviousGranularity();
+
+        assertFalse(highlighter.hasCurrentGranularity());
+        assertHtmlExcludes(previousReadHighlightClass, id);
+      });
 });
