@@ -4,8 +4,8 @@
 import 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 
 import type {AppElement} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
-import {BrowserProxy, currentReadHighlightClass, getReadAloudModel, previousReadHighlightClass, ReadAloudHighlighter, SpeechController} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
-import {assertEquals} from 'chrome-untrusted://webui-test/chai_assert.js';
+import {BrowserProxy, currentReadHighlightClass, getReadAloudModel, previousReadHighlightClass, ReadAloudHighlighter, SelectionController, SpeechController} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {assertEquals, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
 import {microtasksFinished} from 'chrome-untrusted://webui-test/test_util.js';
 
 import {FakeReadingMode} from './fake_reading_mode.js';
@@ -28,6 +28,7 @@ suite('UpdateContentSelectionWithHighlights', () => {
   let app: AppElement;
   let fakeTree: FakeTree;
   let highlighter: ReadAloudHighlighter;
+  let selectionController: SelectionController;
 
   const textNodeIds = [3, 5, 7, 9];
   const texts = [
@@ -47,6 +48,8 @@ suite('UpdateContentSelectionWithHighlights', () => {
     highlighter = new ReadAloudHighlighter();
     ReadAloudHighlighter.setInstance(highlighter);
     SpeechController.setInstance(new SpeechController());
+    selectionController = new SelectionController();
+    SelectionController.setInstance(selectionController);
 
     // Don't use await createApp() when using a FakeTree, as it seems to cause
     // flakiness.
@@ -74,15 +77,17 @@ suite('UpdateContentSelectionWithHighlights', () => {
     let i = 0;
     while (textNodeIds[i]! !== id) {
       fakeTree.highlightNode(textNodeIds[i]!);
-      highlighter.highlightCurrentGranularity(
-          getReadAloudModel().getCurrentTextSegments(), false, true);
+      const segments = getReadAloudModel().getCurrentTextSegments();
+      highlighter.onWillMoveToNextGranularity(segments);
+      highlighter.highlightCurrentGranularity(segments, false, true);
       i++;
     }
 
     // highlight given node
     fakeTree.highlightNode(id);
-    highlighter.highlightCurrentGranularity(
-        getReadAloudModel().getCurrentTextSegments(), false, true);
+    const segments = getReadAloudModel().getCurrentTextSegments();
+    highlighter.onWillMoveToNextGranularity(segments);
+    highlighter.highlightCurrentGranularity(segments, false, true);
     return microtasksFinished();
   }
 
@@ -92,15 +97,17 @@ suite('UpdateContentSelectionWithHighlights', () => {
     let i = 0;
     while (fromId !== textNodeIds[i]!) {
       fakeTree.highlightNode(textNodeIds[i]!);
-      highlighter.highlightCurrentGranularity(
-          getReadAloudModel().getCurrentTextSegments(), false, true);
+      const segments = getReadAloudModel().getCurrentTextSegments();
+      highlighter.onWillMoveToNextGranularity(segments);
+      highlighter.highlightCurrentGranularity(segments, false, true);
       i++;
     }
 
     // highlight given nodes
     fakeTree.setReadingHighlight(fromId, fromOffset, toId, toOffset);
-    highlighter.highlightCurrentGranularity(
-        getReadAloudModel().getCurrentTextSegments(), false, true);
+    const segments = getReadAloudModel().getCurrentTextSegments();
+    highlighter.onWillMoveToNextGranularity(segments);
+    highlighter.highlightCurrentGranularity(segments, false, true);
     return microtasksFinished();
   }
 
@@ -141,7 +148,9 @@ suite('UpdateContentSelectionWithHighlights', () => {
     }
 
     setup(() => {
-      selection = app.getSelection();
+      const appSelection = app.getSelection();
+      assertTrue(!!appSelection);
+      selection = appSelection;
       actualAnchorId = -1;
       actualFocusId = -1;
       actualAnchorOffset = -1;
@@ -384,11 +393,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 0;
       const expectedFocusOffset = 5;
       fakeTree.setSelection(3, expectedAnchorOffset, 3, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[0]!, selection.anchorNode.textContent);
-      assertEquals(texts[0]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[0]!, selection.anchorNode?.textContent);
+      assertEquals(texts[0]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -400,11 +410,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 1;
       const expectedFocusOffset = 7;
       fakeTree.setSelection(3, expectedAnchorOffset, 5, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[0]!, selection.anchorNode.textContent);
-      assertEquals(texts[1]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[0]!, selection.anchorNode?.textContent);
+      assertEquals(texts[1]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -416,11 +427,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 2;
       const expectedFocusOffset = 6;
       fakeTree.setSelection(5, expectedAnchorOffset, 5, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[1]!, selection.anchorNode.textContent);
-      assertEquals(texts[1]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[1]!, selection.anchorNode?.textContent);
+      assertEquals(texts[1]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -432,11 +444,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 6;
       const expectedFocusOffset = 2;
       fakeTree.setSelection(3, expectedAnchorOffset, 5, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[0]!, selection.anchorNode.textContent);
-      assertEquals(texts[1]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[0]!, selection.anchorNode?.textContent);
+      assertEquals(texts[1]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -450,11 +463,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedFocusOffset = 10;
       fakeTree.setSelection(
           highlightId, expectedAnchorOffset, highlightId, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[1]!, selection.anchorNode.textContent);
-      assertEquals(texts[1]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[1]!, selection.anchorNode?.textContent);
+      assertEquals(texts[1]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -466,11 +480,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 2;
       const expectedFocusOffset = 10;
       fakeTree.setSelection(5, expectedAnchorOffset, 5, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[1]!, selection.anchorNode.textContent);
-      assertEquals(texts[1]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[1]!, selection.anchorNode?.textContent);
+      assertEquals(texts[1]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -485,11 +500,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
           const expectedFocusOffset = 9;
           fakeTree.setSelection(
               3, expectedAnchorOffset, 5, expectedFocusOffset);
-          app.updateSelection();
+          selectionController.updateSelection(app.getSelection());
 
           const selection = app.getSelection();
-          assertEquals(texts[0]!, selection.anchorNode.textContent);
-          assertEquals(texts[1]!, selection.focusNode.textContent);
+          assertTrue(!!selection);
+          assertEquals(texts[0]!, selection.anchorNode?.textContent);
+          assertEquals(texts[1]!, selection.focusNode?.textContent);
           assertEquals(expectedAnchorOffset, selection.anchorOffset);
           assertEquals(expectedFocusOffset, selection.focusOffset);
         });
@@ -504,12 +520,13 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 0;
       fakeTree.setSelection(
           highlightId, expectedAnchorOffset, highlightId, highlightStart);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
+      assertTrue(!!selection);
       const expectedSelectedText = texts[2]!.slice(0, highlightStart);
-      assertEquals(expectedSelectedText, selection.anchorNode.textContent);
-      assertEquals(expectedSelectedText, selection.focusNode.textContent);
+      assertEquals(expectedSelectedText, selection.anchorNode?.textContent);
+      assertEquals(expectedSelectedText, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(highlightStart, selection.focusOffset);
     });
@@ -522,16 +539,17 @@ suite('UpdateContentSelectionWithHighlights', () => {
       // select node 7 starting after the end of the highlight
       fakeTree.setSelection(
           highlightId, highlightEnd, highlightId, texts[2]!.length);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       // The highlight should have split node 7 into two nodes - one with the
       // text that's highlighted and another with the remaining text. Since we
       // selected the rest of node 7, the selection corresponds to the
       // entirety of the new second node.
       const selection = app.getSelection();
+      assertTrue(!!selection);
       const expectedSelectedText = texts[2]!.slice(highlightEnd);
-      assertEquals(expectedSelectedText, selection.anchorNode.textContent);
-      assertEquals(expectedSelectedText, selection.focusNode.textContent);
+      assertEquals(expectedSelectedText, selection.anchorNode?.textContent);
+      assertEquals(expectedSelectedText, selection.focusNode?.textContent);
       assertEquals(0, selection.anchorOffset);
       assertEquals(expectedSelectedText.length, selection.focusOffset);
     });
@@ -543,11 +561,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 2;
       const expectedFocusOffset = 8;
       fakeTree.setSelection(7, expectedAnchorOffset, 7, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[2]!, selection.anchorNode.textContent);
-      assertEquals(texts[2]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[2]!, selection.anchorNode?.textContent);
+      assertEquals(texts[2]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -559,11 +578,12 @@ suite('UpdateContentSelectionWithHighlights', () => {
       const expectedAnchorOffset = 4;
       const expectedFocusOffset = 10;
       fakeTree.setSelection(5, expectedAnchorOffset, 7, expectedFocusOffset);
-      app.updateSelection();
+      selectionController.updateSelection(app.getSelection());
 
       const selection = app.getSelection();
-      assertEquals(texts[1]!, selection.anchorNode.textContent);
-      assertEquals(texts[2]!, selection.focusNode.textContent);
+      assertTrue(!!selection);
+      assertEquals(texts[1]!, selection.anchorNode?.textContent);
+      assertEquals(texts[2]!, selection.focusNode?.textContent);
       assertEquals(expectedAnchorOffset, selection.anchorOffset);
       assertEquals(expectedFocusOffset, selection.focusOffset);
     });
@@ -577,13 +597,14 @@ suite('UpdateContentSelectionWithHighlights', () => {
 
           // select all text
           fakeTree.setSelection(3, 0, 9, texts[3]!.length);
-          app.updateSelection();
+          selectionController.updateSelection(app.getSelection());
 
           const selection = app.getSelection();
+          assertTrue(!!selection);
           assertEquals(0, selection.anchorOffset);
           assertEquals(texts[3]!.length, selection.focusOffset);
-          assertEquals(texts[0]!, selection.anchorNode.textContent);
-          assertEquals(texts[3]!, selection.focusNode.textContent);
+          assertEquals(texts[0]!, selection.anchorNode?.textContent);
+          assertEquals(texts[3]!, selection.focusNode?.textContent);
         });
   });
 });
