@@ -3,7 +3,7 @@
 // found in the LICENSE file.
 
 import type {AppElement} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
-import {ContentController, ReadAloudHighlighter, SpeechBrowserProxyImpl, SpeechController, ToolbarEvent, VoiceLanguageController, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {ContentController, getReadAloudModel, ReadAloudHighlighter, SelectionController, SpeechBrowserProxyImpl, SpeechController, ToolbarEvent, VoiceLanguageController, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 import {assertEquals, assertFalse, assertLE, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
 
 import {createApp, createSpeechSynthesisVoice, emitEvent, playFromSelectionWithMockTimer, setSimpleAxTreeWithText} from './common.js';
@@ -14,6 +14,7 @@ suite('WordHighlighting', () => {
   let speech: TestSpeechBrowserProxy;
   let wordBoundaries: WordBoundaries;
   let speechController: SpeechController;
+  let selectionController: SelectionController;
 
   // root htmlTag='#document' id=1
   // ++link htmlTag='a' url='http://www.google.com' id=2
@@ -69,10 +70,15 @@ suite('WordHighlighting', () => {
     wordBoundaries = new WordBoundaries();
     WordBoundaries.setInstance(wordBoundaries);
     ReadAloudHighlighter.setInstance(new ReadAloudHighlighter());
+    selectionController = new SelectionController();
+    SelectionController.setInstance(selectionController);
     speechController = new SpeechController();
     SpeechController.setInstance(speechController);
     ContentController.setInstance(new ContentController());
 
+    // Reset the browser proxy.
+    getReadAloudModel().resetModel?.();
+
     app = await createApp();
     chrome.readingMode.setContentForTesting(axTree, [2, 4]);
     chrome.readingMode.onSpeechRateChange(1);
@@ -145,7 +151,12 @@ suite('WordHighlighting', () => {
     const currentHighlight =
         app.$.container.querySelector('.current-read-highlight');
     assertTrue(!!currentHighlight);
-    assertEquals('4:', currentHighlight.textContent);
+    let expectedHighlight = '4';
+    if (!chrome.readingMode.isTsTextSegmentationEnabled) {
+      // The V8 model appends the colon to the highlight.
+      expectedHighlight += ':';
+    }
+    assertEquals(expectedHighlight, currentHighlight.textContent);
   });
 
   test('word highlighting date across nodes with charLength', () => {
@@ -289,9 +300,10 @@ suite('WordHighlighting', () => {
     range.setStart(anchor, anchorOffset);
     range.setEnd(focus, focusOffset);
 
-    const selection = app.getSelection();
+    const selection = document.getSelection();
     assertTrue(!!selection);
     selection.addRange(range);
+    selectionController.onSelectionChange(selection);
 
     playFromSelectionWithMockTimer(app);
 
@@ -301,7 +313,12 @@ suite('WordHighlighting', () => {
     // Verify that we're highlighting from the selected point.
     assertTrue(!!currentHighlight);
     assertTrue(!!currentHighlight.textContent);
-    assertEquals('This ', currentHighlight.textContent);
+    let expectedHighlight = 'This';
+    if (!chrome.readingMode.isTsTextSegmentationEnabled) {
+      // The V8 model appends a space in the word highlight.
+      expectedHighlight += ' ';
+    }
+    assertEquals(expectedHighlight, currentHighlight.textContent);
     // Verify that the word boundary state has been reset.
     assertFalse(wordBoundaries.hasBoundaries());
   });
